@@ -1,13 +1,10 @@
 DOMAIN = 'gene_info'
 FILENAME = 'gene_info.sqlite'
-TITLE = 'NCBI Gene Information'
+TITLE = 'NCBI Gene database'
 TAGS = ['NCBI', 'Gene names', 'Gene Ids', 'Description', 'Essential']
 FTP_FILENAME = 'gene_info.gz'
 FTP_URL = 'ftp://ftp.ncbi.nlm.nih.gov/gene/DATA/gene_info.gz'
 
-# dictyBase gene names
-DICTY_GENE_NAMES = \
-    'http://www.dictybase.org/db/cgi-bin/dictyBase/download/download.pl?area=general&ID=gene_information.txt'
 
 # NCBI_INFO - order is important
 GENE_INFO_TAGS = ['tax_id',
@@ -40,3 +37,7 @@ MAP_SYMBOLS = 'symbols'
 MAP_SYNONYMS = 'synonyms'
 MAP_LOCUS = 'locus_tag'
 
+# OWGeneInfo settings
+GENE_INFO_HEADER_LABELS = ['NCBI ID', 'Ensembl ID', 'Symbol', 'Locus Tag', 'Chromosome', 'Description', 'Synonyms', 'Nomenclature']
+NCBI_DETAIL_LINK = 'http://www.ncbi.nlm.nih.gov/sites/entrez?Db=gene&Cmd=ShowDetailView&TermToSearch={}'
+ENSEMBL_DETAIL_LINK = 'http://www.ensembl.org/id/{}'
