@@ -10,7 +10,6 @@ import Orange.data
 import logging
 
 
-from requests.exceptions import ConnectTimeout
 from collections import defaultdict
 from functools import reduce
 from concurrent.futures import Future
@@ -32,11 +31,10 @@ from Orange.widgets.utils.concurrent import (
 )
 from Orange.widgets.utils.concurrent import Task
 from Orange.widgets import widget, gui, settings
-from Orange.widgets.utils.datacaching import data_hints
 from orangecontrib.bioinformatics import go
 from orangecontrib.bioinformatics.ncbi import taxonomy
 from orangecontrib.bioinformatics.utils import serverfiles, statistics
-from orangecontrib.bioinformatics.widgets.utils.data import GENE_NAME, TAX_ID
+from orangecontrib.bioinformatics.widgets.utils.data import GENE_AS_ATTRIBUTE_NAME, TAX_ID
 from orangecontrib.bioinformatics.go.config import DOMAIN, FILENAME_ONTOLOGY, FILENAME_ANNOTATION
 
 
@@ -298,6 +296,7 @@ class OWGOBrowser(widget.OWWidget):
 
         self.listView.header().setSectionsClickable(True)
         self.listView.header().setSortIndicatorShown(True)
+        self.listView.header().setSortIndicator(self.DAGcolumns.index('p-value'), Qt.DescendingOrder)
         self.listView.setSortingEnabled(True)
         self.listView.setItemDelegateForColumn(
             6, EnrichmentColumnItemDelegate(self))
@@ -311,6 +310,7 @@ class OWGOBrowser(widget.OWWidget):
         self.sigTerms.setHeaderLabels(self.DAGcolumns)
         self.sigTerms.setSortingEnabled(True)
         self.sigTerms.setSelectionMode(QTreeView.ExtendedSelection)
+        self.sigTerms.header().setSortIndicator(self.DAGcolumns.index('p-value'), Qt.DescendingOrder)
         self.sigTerms.setItemDelegateForColumn(
             6, EnrichmentColumnItemDelegate(self))
 
@@ -339,7 +339,7 @@ class OWGOBrowser(widget.OWWidget):
                 name=taxonomy.common_taxid_to_name(AnnotationSlot.parse_tax_id(annotation_file)),
                 filename=FILENAME_ANNOTATION.format(AnnotationSlot.parse_tax_id(annotation_file))
             )
-            for _, annotation_file in serverfiles.ServerFiles().listfiles(DOMAIN)
+            for _, annotation_file in set(serverfiles.ServerFiles().listfiles(DOMAIN) + serverfiles.listfiles(DOMAIN))
             if annotation_file != FILENAME_ONTOLOGY
 
         ]
@@ -389,7 +389,8 @@ class OWGOBrowser(widget.OWWidget):
             for var in self.candidateGeneAttrs:
                 self.geneAttrIndexCombo.addItem(*gui.attributeItem(var))
 
-            tax_id = data_hints.get_hint(data, TAX_ID, '')
+            tax_id = str(data.attributes.get(TAX_ID, ''))
+
             if tax_id is not None:
                 _c2i = {a.taxid: i for i, a in enumerate(self.availableAnnotations)}
                 try:
@@ -397,7 +398,7 @@ class OWGOBrowser(widget.OWWidget):
                 except KeyError:
                     pass
 
-            self.useAttrNames = data_hints.get_hint(data, GENE_NAME, default=self.useAttrNames)
+            self.useAttrNames = data.attributes.get(GENE_AS_ATTRIBUTE_NAME, self.useAttrNames)
 
             self.geneAttrIndex = min(self.geneAttrIndex, len(self.candidateGeneAttrs) - 1)
             if len(self.candidateGeneAttrs) == 0:
@@ -538,7 +539,7 @@ class OWGOBrowser(widget.OWWidget):
         # otherwise
         assert self.__state == State.Ready
         annotation = self.availableAnnotations[self.annotationIndex]
-        go_files = serverfiles.listfiles(DOMAIN)
+        go_files = [fname for domain, fname in serverfiles.listfiles(DOMAIN)]
         files = []
 
         if annotation.filename not in go_files:
@@ -826,7 +827,14 @@ class OWGOBrowser(widget.OWWidget):
         fromParentDict = {}
         self.termListViewItemDict = {}
         self.listViewItems = []
-        enrichment = lambda t: len(t[0]) / t[2] * (len(self.referenceGenes) / len(self.clusterGenes))
+
+        def enrichment(t):
+            try:
+                return len(t[0]) / t[2] * (len(self.referenceGenes) / len(self.clusterGenes))
+            except ZeroDivisionError:
+                # TODO: find out why this happens
+                return 0
+
         maxFoldEnrichment = max([enrichment(term) for term in self.graph.values()] or [1])
 
         def addNode(term, parent, parentDisplayNode):
