@@ -23,12 +23,11 @@ from Orange.widgets.gui import (
 from Orange.widgets.widget import OWWidget, Msg
 from Orange.widgets.utils import itemmodels
 from Orange.widgets.settings import Setting, ContextSetting
-from Orange.widgets.utils.datacaching import data_hints
 from Orange.widgets.utils.signals import Output, Input
 
 from Orange.data import DiscreteVariable, StringVariable, Domain, Table
 
-from orangecontrib.bioinformatics.widgets.utils.data import TAX_ID, GENE_NAME
+from orangecontrib.bioinformatics.widgets.utils.data import TAX_ID, GENE_AS_ATTRIBUTE_NAME
 from orangecontrib.bioinformatics.widgets.utils.concurrent import Worker
 from orangecontrib.bioinformatics.utils import serverfiles
 from orangecontrib.bioinformatics.ncbi import gene, taxonomy
@@ -50,7 +49,7 @@ def hierarchy_tree(tax_id, gene_sets):
         if set_hierarchy:
             collect(col[set_hierarchy[0]], set_hierarchy[1:])
 
-    for hierarchy, t_id, _ in gene_sets:
+    for hierarchy, t_id in gene_sets:
         collect(collection[t_id], hierarchy)
 
     return tax_id, collection[tax_id]
@@ -85,7 +84,7 @@ def get_collections(gene_sets, mapped_genes, partial_result, progress_callback):
 def download_gene_sets(gene_sets, progress_callback):
 
     # get only those sets that are not already downloaded
-    for hierarchy, tax_id in [(hierarchy, tax_id) for hierarchy, tax_id, local in gene_sets if not local]:
+    for hierarchy, tax_id in [(hierarchy, tax_id) for hierarchy, tax_id in gene_sets]:
 
         serverfiles.localpath_download(geneset.DOMAIN, geneset.filename(hierarchy, tax_id),
                                        callback=progress_callback.emit)
@@ -205,9 +204,11 @@ class OWGeneSets(OWWidget):
 
     def _update_gene_matcher(self):
         self._gene_names_from_table()
-        if self.gene_matcher:
-            self.gene_matcher.genes = self.input_genes
-            self.gene_matcher.organism = self._get_selected_organism()
+        if not self.gene_matcher:
+            self.gene_matcher = gene.GeneMatcher(self._get_selected_organism())
+
+        self.gene_matcher.genes = self.input_genes
+        self.gene_matcher.organism = self._get_selected_organism()
 
     def on_input_option_change(self):
         self._update_gene_matcher()
@@ -217,7 +218,6 @@ class OWGeneSets(OWWidget):
     def handle_input(self, data):
         if data:
             self.input_data = data
-            self.gene_matcher = gene.GeneMatcher(self._get_selected_organism())
 
             self.gene_column_combobox.clear()
             self.column_candidates = [attr for attr in data.domain.variables + data.domain.metas
@@ -226,8 +226,9 @@ class OWGeneSets(OWWidget):
             for var in self.column_candidates:
                 self.gene_column_combobox.addItem(*attributeItem(var))
 
-            self.tax_id = str(data_hints.get_hint(self.input_data, TAX_ID))
-            self.use_attr_names = data_hints.get_hint(self.input_data, GENE_NAME, default=self.use_attr_names)
+            self.tax_id = str(self.input_data.attributes.get(TAX_ID, ''))
+            self.use_attr_names = self.input_data.attributes.get(GENE_AS_ATTRIBUTE_NAME, self.use_attr_names)
+
             self.gene_col_index = min(self.gene_col_index, len(self.column_candidates) - 1)
 
             if self.tax_id in self.organisms:
@@ -318,6 +319,8 @@ class OWGeneSets(OWWidget):
 
                 self.data_view.resizeColumnToContents(i)
 
+            self.filter_proxy_model.setSourceModel(self.data_model)
+
     def populate_data_model(self, partial_result):
         assert threading.current_thread() == threading.main_thread()
 
@@ -382,6 +385,12 @@ class OWGeneSets(OWWidget):
         self.progress_bar = ProgressBar(self, iterations=iterations)
         self.setStatusMessage('displaying gene sets')
 
+        if not only_selected_hier:
+            self.progress_bar.finish()
+            self.setStatusMessage('')
+            self.hierarchy_widget.setDisabled(False)
+            return
+
         for selected_hierarchy in only_selected_hier:
             self.threadpool.start(self.workers[selected_hierarchy])
 
@@ -512,12 +521,12 @@ class OWGeneSets(OWWidget):
     def init_item_model(self):
         if self.data_model:
             self.data_model.clear()
+            self.filter_proxy_model.setSourceModel(None)
         else:
             self.data_model = QStandardItemModel()
 
         self.data_model.setSortRole(Qt.UserRole)
         self.data_model.setHorizontalHeaderLabels(DATA_HEADER_LABELS)
-        self.filter_proxy_model.setSourceModel(self.data_model)
 
     def sizeHint(self):
         return QSize(1280, 960)
